==> moodle-1.5-pgsql.tgz: moodle/lang/en/scorm.php <==
<?php // $Id$

#------------------------------------------------------------
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMs';
#------------------------------------------------------------

$string['asset'] = 'Asset';
$string['autocontinue'] = 'Auto-Continue';
$string['browse'] = 'Preview';
$string['browsed'] = 'Browsed';
$string['browsemode'] = 'Browse Mode';
$string['chooseapacket'] = 'Choose or update a package';
$string['completed'] = 'Completed';
$string['coursestruct'] = 'Course structure';
$string['coursepacket'] = 'Course package';
$string['entercourse'] = 'Enter course';
$string['failed'] = 'Failed';
$string['gradeaverage'] = 'Average grade';
$string['gradehighest'] = 'Highest grade';
$string['grademethod'] = 'Grading method';
$string['gradescoes'] = 'Scoes situation';
$string['gradesum'] = 'Sum grade';
$string['guestsno'] = 'Guests can not view scorm courses';
$string['incomplete'] = 'Incomplete';
$string['next'] = 'Continue';
$string['noreports'] = 'No report to display';
$string['normal'] = 'Normal';
$string['notattempted'] = 'Not attempted';
$string['mode'] = 'Mode';
$string['organizations'] = 'Organizations';
$string['organization'] = 'Organization';
$string['passed'] = 'Passed';
$string['prev'] = 'Previous';
$string['report'] = 'Report';
$string['review'] = 'Review';
$string['scoes'] = 'Scoes';
$string['score'] = 'Score';
$string['viewallreports'] = 'View reports for $a attempts';
$string['display'] = 'Display';
$string['expcoll'] = 'Expand/Collide';
$string['exit'] = 'Exit from SCORM course';
$string['details'] = 'SCO track details';
$string['enablebrowse'] = 'Enable preview mode';
$string['frameheight'] = 'This preference set the default height of SCO frame';
$string['framewidth'] = 'This preference set the default width of SCO frame';
$string['width'] = 'Width';
$string['height'] = 'Height';
$string['trackingloose'] = 'WARNING: The tracking data of this package will be lost!';
$string['popup'] = 'Open current SCO in a new window';
$string['totaltime'] = 'Time';
$string['noactivity'] = 'Nothing to report';
$string['firstaccess'] = 'First access';
$string['lastaccess'] = 'Last access';

// Validation
$string['attr_error'] = 'Bad value for attribute ($a->attr) in tag $a->tag.';
$string['badmanifest'] ='Some manifest errors: see errors log';
$string['datadir'] = 'Filesystem Error: Can\'t create course data directory';
$string['errorlogs'] = 'Errors log';
$string['found'] = 'Manifest found';
$string['no_attributes'] = 'Tag $a->tag must have attributes';
$string['no_children'] = 'Tag $a->tag must have children';
$string['nomanifest'] = 'Manifest not found';
$string['not_corr_type'] = 'Type mismatch for tag $a->tag';
$string['missing_attribute'] = 'Missing attribute $a->attr in tag $a->tag';
$string['missing_tag'] = 'Missing tag $a->tag';
$string['packagedir'] = 'Filesystem Error: Can\'t create package directory';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['position_error'] = 'The $a->tag tag can\'t be child of $a->parent tag';
$string['regular'] = 'Regular Manifest';
$string['syntax'] = 'Syntax error';
$string['tag_error'] = 'Unknown tag ($a->tag) with this content: $a->value';
$string['too_many_attributes'] = 'Tag $a->tag has too many attributes';
$string['too_many_children'] = 'Tag $a->tag has too many children';
$string['domxml'] = 'DOMXML external library';
$string['validateascorm'] = 'Validate a package';
$string['validation'] = 'Validation result';
$string['validationtype'] = 'This preference set the DOMXML library used for validating SCORM Manifest. If you don\'t know leave the selected choice.';
$string['versionwarning'] = 'The manifest version is older than 1.3, warning at $a->tag tag';
?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/en/scorm.php <==
<?php // $Id$

#------------------------------------------------------------
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMs';
#------------------------------------------------------------

$string['asset'] = 'Asset';
$string['autocontinue'] = 'Auto-Continue';
$string['browse'] = 'Preview';
$string['browsed'] = 'Browsed';
$string['browsemode'] = 'Browse Mode';
$string['chooseapacket'] = 'Choose or update a package';
$string['completed'] = 'Completed';
$string['coursestruct'] = 'Course structure';
$string['coursepacket'] = 'Course package';
$string['entercourse'] = 'Enter course';
$string['failed'] = 'Failed';
$string['gradeaverage'] = 'Average grade';
$string['gradehighest'] = 'Highest grade';
$string['grademethod'] = 'Grading method';
$string['gradescoes'] = 'Scoes situation';
$string['gradesum'] = 'Sum grade';
$string['guestsno'] = 'Guests can not view scorm courses';
$string['incomplete'] = 'Incomplete';
$string['next'] = 'Continue';
$string['noreports'] = 'No report to display';
$string['normal'] = 'Normal';
$string['notattempted'] = 'Not attempted';
$string['mode'] = 'Mode';
$string['organizations'] = 'Organizations';
$string['organization'] = 'Organization';
$string['passed'] = 'Passed';
$string['prev'] = 'Previous';
$string['report'] = 'Report';
$string['review'] = 'Review';
$string['scoes'] = 'Scoes';
$string['score'] = 'Score';
$string['viewallreports'] = 'View reports for $a attempts';
$string['display'] = 'Display';
$string['expcoll'] = 'Expand/Collide';
$string['exit'] = 'Exit from SCORM course';
$string['details'] = 'SCO track details';
$string['enablebrowse'] = 'Enable preview mode';
$string['frameheight'] = 'This preference set the default height of SCO frame';
$string['framewidth'] = 'This preference set the default width of SCO frame';
$string['stagesize'] = 'Frame/Windows size';
$string['width'] = 'Width';
$string['height'] = 'Height';
$string['trackingloose'] = 'WARNING: The tracking data of this package will be lost!';
$string['popup'] = 'Open Learning Objects in a new window';
$string['totaltime'] = 'Time';
$string['noactivity'] = 'Nothing to report';
$string['firstaccess'] = 'First access';
$string['lastaccess'] = 'Last access';
$string['scormcourse'] = 'SCORM Course';
$string['advanced'] = 'Advanced';

// Validation
$string['attr_error'] = 'Bad value for attribute ($a->attr) in tag $a->tag.';
$string['badmanifest'] ='Some manifest errors: see errors log';
$string['datadir'] = 'Filesystem Error: Can\'t create course data directory';
$string['errorlogs'] = 'Errors log';
$string['found'] = 'Manifest found';
$string['no_attributes'] = 'Tag $a->tag must have attributes';
$string['no_children'] = 'Tag $a->tag must have children';
$string['nomanifest'] = 'Manifest not found';
$string['not_corr_type'] = 'Type mismatch for tag $a->tag';
$string['missing_attribute'] = 'Missing attribute $a->attr in tag $a->tag';
$string['missing_tag'] = 'Missing tag $a->tag';
$string['packagedir'] = 'Filesystem Error: Can\'t create package directory';
$string['packagefile'] = 'No package file specified';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['position_error'] = 'The $a->tag tag can\'t be child of $a->parent tag';
$string['regular'] = 'Regular Manifest';
$string['syntax'] = 'Syntax error';
$string['tag_error'] = 'Unknown tag ($a->tag) with this content: $a->value';
$string['too_many_attributes'] = 'Tag $a->tag has too many attributes';
$string['too_many_children'] = 'Tag $a->tag has too many children';
$string['domxml'] = 'DOMXML external library';
$string['validateascorm'] = 'Validate a package';
$string['validation'] = 'Validation result';
$string['validationtype'] = 'This preference set the DOMXML library used for validating SCORM Manifest. If you don\'t know leave the selected choice.';
$string['versionwarning'] = 'The manifest version is older than 1.3, warning at $a->tag tag';
?>
